@@ -5,10 +5,13 @@
 package utils
 
 import (
+	"bufio"
 	"fmt"
 	"io"
 	"os"
 	"path"
+	"path/filepath"
+	"regexp"
 )
 
 func CopyFile(src, dest string) (err error) {
@@ -222,5 +225,90 @@ func symlinkIsDir(link string) bool {
 	if len(dir) == 0 {
 		return IsDir(target)
 	}
+
 	return IsDir(path.Join(dir, target))
 }
+
+func FindFileInDir(dir string, targetFile string) (string, error) {
+	var result string
+	err := filepath.Walk(dir, func(path string, info os.FileInfo, err error) error {
+		if err != nil {
+			return err
+		}
+
+		if !info.IsDir() && info.Name() == targetFile {
+			result = path
+			return filepath.SkipDir
+
+		}
+
+		return nil
+	})
+
+	if err != nil {
+		return "", err
+	}
+
+	if result == "" {
+		return "", fmt.Errorf("file '%s' not found in directory '%s'", targetFile, dir)
+	}
+
+	return result, nil
+}
+
+func FindFileInDirRegexp(dir string, re *regexp.Regexp) ([]string, error) {
+	var result []string
+	err := filepath.Walk(dir, func(path string, info os.FileInfo, err error) error {
+		if err != nil {
+			return err
+		}
+
+		if len(result) > 0 {
+			return filepath.SkipDir
+		}
+
+		if !info.IsDir() {
+			result = re.FindStringSubmatch(info.Name())
+			if len(result) > 0 {
+				result[0] = path
+				return filepath.SkipDir
+			}
+		}
+
+		return nil
+	})
+
+	if err != nil {
+		return nil, err
+	}
+
+	if len(result) == 0 {
+		return result, fmt.Errorf("file '%s' not found in directory '%s'", re.String(), dir)
+	}
+
+	return result, nil
+}
+
+func FindContentInFileRegexp(filename string, re *regexp.Regexp) (int, []string, error) {
+	file, err := os.Open(filename)
+	if err != nil {
+		return 0, nil, err
+	}
+
+	defer file.Close()
+
+	scanner := bufio.NewScanner(file)
+
+	for i := 1; scanner.Scan(); i++ {
+		matches := re.FindStringSubmatch(scanner.Text())
+		if len(matches) > 0 {
+			return i, matches, nil
+		}
+	}
+
+	if err := scanner.Err(); err != nil {
+		return 0, nil, err
+	}
+
+	return 0, nil, fmt.Errorf("content '%s' not found in file '%s'", re.String(), filename)
+}
